.. NUAAL documentation master file, created by
   sphinx-quickstart on Mon Apr 23 23:04:37 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NUAAL's documentation!
=================================
This project aims to bring multiple ways of communicating with networking gear under one unified API. This should allow network engineers to gather information about the network configuration in a fast and simple manner. In the early stage, this project focuses mainly on retrieving the information from the devices, not so much on performing configuration changes.

.. toctree::
   :maxdepth: 3

   Connections/index
   Parsers/index
   Models/index
   Writers/index
   Discovery/index

